@@ -9,7 +9,7 @@
  *
  * GTick is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
- * the Free Software Foundation; either version 2 of the License, or
+ * the Free Software Foundation; either version 3 of the License, or
  * (at your option) any later version.
  *
  * GTick is distributed in the hope that it will be useful,
@@ -18,8 +18,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with GTick; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
+ * along with GTick; if not, see <http://www.gnu.org/licenses/>.
  *
  */
 
@@ -345,13 +344,9 @@ int generate_sine(int samplefreq, double sinfreq, double sigdur, double fadedur,
 int sndfile_get_samples(const char* filename,
                         short** samples, int* rate, int* channels)
 {
-  short* s;
   SF_INFO sfinfo;
   SNDFILE* sf;
   int frames;
-  int bufsize = 1024 * 16; /* number of frames in one read */
-  int i = 0; /* counter */
-  int result = 1; /* temporary result in read loop */
 
   sfinfo.format = 0;
   if (!(sf = sf_open(filename, SFM_READ, &sfinfo))) {
@@ -366,15 +361,11 @@ int sndfile_get_samples(const char* filename,
   *rate = sfinfo.samplerate;
   *channels = sfinfo.channels ;
 
-  s = (short*) g_malloc(frames * sizeof(short) * sfinfo.channels);
-  
-  while (i < frames && result != 0) {
-    result = sf_readf_short(sf, &s[i * sfinfo.channels], bufsize);
-    i += result;
-  }
+  *samples = (short*) g_malloc(frames * sizeof(short) * sfinfo.channels);
+ 
+  sf_readf_short(sf, *samples, frames);
   
   sf_close(sf);
-  *samples = s;
   return frames;
 }
 #endif /* WITH_SNDFILE */
